@@ -468,25 +468,6 @@ def readlines(filepath, start=0, n=None):
 	        yield content
 
 
-class AverageMeter(object):
-    """ Computes and stores the average and current value
-    """
-    def __init__(self):
-        self.reset()
-
-    def reset(self):
-        self.val = 0
-        self.avg = 0
-        self.sum = 0
-        self.count = 0
-
-    def update(self, val, n=1):
-        self.val = val
-        self.sum += val * n
-        self.count += n
-        self.avg = self.sum / self.count
-
-
 def remove_punc(text):
     """ 中文去标点 """
     text = not_zh.sub("", text)
